#!/bin/bash

# SSD-Gerät, das überprüft werden soll
SSD_DEVICE="/dev/sda1"

# Erstelle das Mount-Verzeichnis, falls es nicht existiert
mount_dir="/media/sda1"

# Skript, um Informationen über /dev/sda1 anzuzeigen und zu mounten
echo "Lade Informationen über $SSD_DEVICE..."

# Führe den blkid-Befehl für /dev/sda1 aus und speichere die Ausgabe in einer Variable
device_info=$(blkid $SSD_DEVICE)

# Überprüfe, ob der blkid-Befehl erfolgreich war
if [ $? -eq 0 ]; then
    echo "Informationen über $SSD_DEVICE:"
    echo "$device_info"

    # Prüfen, ob das Gerät bereits gemountet ist
    mount | grep -q "$SSD_DEVICE"
    if [ $? -ne 0 ]; then
        echo "$SSD_DEVICE ist nicht gemountet. Versuche, das Gerät zu mounten..."

        # Erstelle das Mount-Verzeichnis, falls es nicht existiert
        if [ ! -d "$mount_dir" ]; then
            mkdir -p "$mount_dir"
        fi

        # Mounten des Geräts
        mount "$SSD_DEVICE" "$mount_dir"

        # Überprüfen, ob das Mounten erfolgreich war, ansonsten wird ein reboot ausgelöst
        if [ $? -eq 0 ]; then
            echo "$SSD_DEVICE wurde erfolgreich unter $mount_dir gemountet."
            touch /tmp/.ssd.mount
        else
            echo "Fehler: Konnte $SSD_DEVICE nicht mounten."
            reboot
        fi
    else
        echo "$SSD_DEVICE ist bereits gemountet."
        touch /tmp/.ssd.ready
    fi
else
    # wahrscheinlich ist keine SSD / HDD angeschlossen oder diese ist defekt
    echo "Fehler: blkid konnte keine Informationen über $SSD_DEVICE abrufen."
    touch /tmp/.ssd.error
fi
